package lightcontainer.protocol.rules.reader;

import lightcontainer.domains.client.Context;
import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.ProtocolReader;
import lightcontainer.protocol.rules.writer.SaveFileErrorRule;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

/**
 * Règle permettant de de confirmer la sauvegrade d'un fichier.
 */
public class SendErrorRule extends ProtocolReader {


    // Constants
    private static final String PATTERN = "^SEND_ERROR\r\n$";

    private static final String NAME = "SEND_ERROR";

    private ProtocolRepository protocolRep;
    private final String storagePath;

    // Constructor
    public SendErrorRule(ProtocolRepository protocolRep, String storagePath) {
        super(NAME, PATTERN);
        this.protocolRep = protocolRep;
        this.storagePath = storagePath;
    }


    @Override
    protected ProtocolResult onExecuted(Context context, String... data) {
        ProtocolResult result = new ProtocolResult(context);
        result.setResultCommand(protocolRep.executeWriter(context, SaveFileErrorRule.NAME), ResultCmdReceiver.CLIENT);

        // Suppression du fichier temporaire dans le stockage du FFE
        String hashedFileName = context.getHashedFileName(context.getDataString("fileName"));
        try {
            Files.deleteIfExists(Path.of(String.format("%s/%s", this.storagePath, hashedFileName)));
        } catch (IOException e) {}

        return result;
    }
}
