package lightcontainer.protocol.rules.reader;

import lightcontainer.domains.client.Context;
import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.ProtocolReader;
import lightcontainer.protocol.rules.writer.SaveFileOkRule;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

/**
 * Règle permettant de de confirmer la sauvegrade d'un fichier.
 */
public class SendOkRule extends ProtocolReader {

    // Constants
    private static final String PATTERN = "^SEND_OK\r\n$";

    private static final String NAME = "SEND_OK";

    private final ProtocolRepository protocolRep;
    private final String storagePath;

    // Constructor
    public SendOkRule(ProtocolRepository protocolRep, String storagePath) {
        super(NAME, PATTERN);
        this.protocolRep = protocolRep;
        this.storagePath = storagePath;
    }


    @Override
    protected ProtocolResult onExecuted(Context context, String... data) {
        ProtocolReader.ProtocolResult result = new ProtocolReader.ProtocolResult(context);
        result.setResultCommand(protocolRep.executeWriter(context, SaveFileOkRule.NAME), ResultCmdReceiver.CLIENT);

        // Sauvegarder dans JSON
        context.addFile(context.getDataString("fileName"), context.getDataString("fileNameSalt"), context.getDataInt("size"), context.getDataString("iv"), context.getDomain());

        // Suppression du fichier temporaire dans le stockage du FFE
        String hashedFileName = context.getHashedFileName(context.getDataString("fileName"));
        try {
            Files.deleteIfExists(Path.of(String.format("%s/%s", storagePath, hashedFileName)));
        } catch (IOException e) {}

        return result;
    }
}
